evaluix
=======

.. image:: https://img.shields.io/badge/version-1.0.0-blue
   :target: https://img.shields.io/badge/version-1.0.0-blue
.. image:: https://img.shields.io/badge/License-MIT-blue
   :target: https://github.com/exp4-age/evaluix/blob/main/LICENSE

Data Evaluation Software of Arbeitsgruppe Ehresmann (Magnetism)


Installation
------------

Install with ::

    pip install evaluix

If you want to help develop and contribute to the package, first clone
the repository to your PC and install in editable mode (detailed 
tutorial is about to come)::

    git clone https://github.com/exp4-age/evaluix.git
    cd evaluix
    pip install -e .

Recommendation for Students and Beginners
-----------------------------------------

Install Anaconda and create a new environment with Python 3.9 or higher. Activate it in an anaconda prompt
and install evaluix as follows ::

    conda create -n myevaluix python=3.9

    conda activate myevaluix

    conda install pip (if necessary)

    pip install evaluix

Now you can start the software by typing `evaluix` in the anaconda prompt ::

    conda activate myevaluix (if not already activated)

    evaluix

Documentation
-------------

About to come.

Contributing
------------

About to come